@@ -1,4 +1,4 @@
-#define NLANGUAGES 1148
+#define NLANGUAGES 1154
 struct LanguageScripts
 {
   const gchar *language;
@@ -235,6 +235,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "dyu", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "dz_BT", { N_("Tibetan"), NULL }, { 0x54696274, 0 } },
     { "ebu", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "ecy", { N_("Cypriot"), NULL }, { 0x43707274, 0 } },
     { "ee", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "efi", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "egl", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -420,6 +421,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "fa_IR", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
     { "fan", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "ff", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "ff_CM", { N_("Adlam"), NULL }, { 0x41646c6d, 0 } },
     { "ff_GN", { N_("Adlam"), NULL }, { 0x41646c6d, 0 } },
     { "ff_SN", { N_("Adlam"), NULL }, { 0x41646c6d, 0 } },
     { "ffm", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -514,15 +516,15 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "gld", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
     { "glk", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
     { "gmh", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "gmy", { N_("Linear_B"), NULL }, { 0x4c696e62, 0 } },
     { "gn_PY", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "goh", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
-    { "gom", { N_("Devanagari"), NULL }, { 0x44657661, 0 } },
     { "gon", { N_("Devanagari"), N_("Telugu"), NULL }, { 0x44657661, 0x54656c75, 0 } },
     { "gor", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "gos", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "got", { N_("Gothic"), NULL }, { 0x476f7468, 0 } },
     { "grb", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
-    { "grc", { N_("Cypriot"), N_("Greek"), N_("Linear_B"), NULL }, { 0x43707274, 0x4772656b, 0x4c696e62, 0 } },
+    { "grc", { N_("Greek"), NULL }, { 0x4772656b, 0 } },
     { "grt", { N_("Bengali"), NULL }, { 0x42656e67, 0 } },
     { "gsw_CH", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "gsw_LI", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -601,12 +603,13 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "jv", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "jv_ID", { N_("Javanese"), NULL }, { 0x4a617661, 0 } },
     { "ka_GE", { N_("Georgian"), NULL }, { 0x47656f72, 0 } },
-    { "kaa", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
+    { "kaa", { N_("Cyrillic"), N_("Latin"), NULL }, { 0x4379726c, 0x4c61746e, 0 } },
     { "kab", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "kac", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "kaj", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "kam", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "kao", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "kaw", { N_("Balinese"), N_("Javanese"), N_("Kawi"), NULL }, { 0x42616c69, 0x4a617661, 0x4b617769, 0 } },
     { "kbd", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
     { "kca", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
     { "kcg", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -639,10 +642,11 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "km_KH", { N_("Khmer"), NULL }, { 0x4b686d72, 0 } },
     { "kmb", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "kn", { N_("Kannada"), NULL }, { 0x4b6e6461, 0 } },
+    { "knn", { N_("Devanagari"), NULL }, { 0x44657661, 0 } },
     { "ko_KP", { N_("Hangul"), NULL }, { 0x48616e67, 0 } },
     { "ko_KR", { N_("Hangul"), NULL }, { 0x48616e67, 0 } },
     { "koi", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
-    { "kok", { N_("Devanagari"), NULL }, { 0x44657661, 0 } },
+    { "kok", { N_("Devanagari"), N_("Latin"), NULL }, { 0x44657661, 0x4c61746e, 0 } },
     { "kos", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "kpe", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "kpy", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
@@ -695,6 +699,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "ljp", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "lki", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
     { "lkt", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "lld", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "lmn", { N_("Telugu"), NULL }, { 0x54656c75, 0 } },
     { "lmo", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "ln", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -743,6 +748,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "mgp", { N_("Devanagari"), NULL }, { 0x44657661, 0 } },
     { "mgy", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "mh_MH", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "mhn", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "mi_NZ", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "mic", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "min", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -1143,14 +1149,14 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "zgh", { N_("Tifinagh"), NULL }, { 0x54666e67, 0 } },
     { "zh_CN", { N_("Han"), NULL }, { 0x48616e69, 0 } },
     { "zh_HK", { N_("Han"), NULL }, { 0x48616e69, 0 } },
-    { "zh_ID", { N_("Bopomofo"), N_("Phags_Pa"), NULL }, { 0x426f706f, 0x50686167, 0 } },
+    { "zh_ID", { N_("Bopomofo"), N_("Latin"), N_("Phags_Pa"), NULL }, { 0x426f706f, 0x4c61746e, 0x50686167, 0 } },
     { "zh_MO", { N_("Han"), NULL }, { 0x48616e69, 0 } },
-    { "zh_MY", { N_("Bopomofo"), N_("Phags_Pa"), NULL }, { 0x426f706f, 0x50686167, 0 } },
+    { "zh_MY", { N_("Bopomofo"), N_("Latin"), N_("Phags_Pa"), NULL }, { 0x426f706f, 0x4c61746e, 0x50686167, 0 } },
     { "zh_SG", { N_("Han"), NULL }, { 0x48616e69, 0 } },
-    { "zh_TH", { N_("Bopomofo"), N_("Phags_Pa"), NULL }, { 0x426f706f, 0x50686167, 0 } },
+    { "zh_TH", { N_("Bopomofo"), N_("Latin"), N_("Phags_Pa"), NULL }, { 0x426f706f, 0x4c61746e, 0x50686167, 0 } },
     { "zh_TW", { N_("Han"), NULL }, { 0x48616e69, 0 } },
-    { "zh_US", { N_("Bopomofo"), N_("Phags_Pa"), NULL }, { 0x426f706f, 0x50686167, 0 } },
-    { "zh_VN", { N_("Bopomofo"), N_("Phags_Pa"), NULL }, { 0x426f706f, 0x50686167, 0 } },
+    { "zh_US", { N_("Bopomofo"), N_("Latin"), N_("Phags_Pa"), NULL }, { 0x426f706f, 0x4c61746e, 0x50686167, 0 } },
+    { "zh_VN", { N_("Bopomofo"), N_("Latin"), N_("Phags_Pa"), NULL }, { 0x426f706f, 0x4c61746e, 0x50686167, 0 } },
     { "zmi", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "zu", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "zun", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
