@@ -35,9 +35,9 @@ var MainWindow = GObject.registerClass({
     Template: 'resource:///org/gnome/Characters/window.ui',
     InternalChildren: [
         'searchButton', 'search-bar', 'searchEntry',
-        'container', 'sidebar', 'loadingSpinner',
-        'splitView', 'mainStack', 'contentChild',
-        'charactersView', 'scrolledWindow', 'primaryMenuButton',
+        'container', 'sidebar', 'splitView',
+        'mainStack', 'contentChild', 'charactersView',
+        'scrolledWindow', 'primaryMenuButton',
     ],
     Properties: {
         'max-recent-characters': GObject.ParamSpec.uint(
@@ -119,10 +119,8 @@ var MainWindow = GObject.registerClass({
 
         this._charactersView.connect('notify::loading', view => {
             if (view.loading) {
-                this._loadingSpinner.start();
                 this._mainStack.visible_child_name = 'loading';
             } else {
-                this._loadingSpinner.stop();
                 this._mainStack.visible_child_name = 'character-list';
                 this._mainStack.queue_draw();
             }
@@ -161,7 +159,7 @@ var MainWindow = GObject.registerClass({
     }
 
     _about() {
-        const aboutWindow = new Adw.AboutWindow({
+        const aboutDialog = new Adw.AboutDialog({
             application_name: _('Characters'),
             application_icon: pkg.name,
             developer_name: _('The GNOME Project'),
@@ -179,11 +177,10 @@ var MainWindow = GObject.registerClass({
             license_type: Gtk.License.GPL_2_0,
             version: pkg.version,
             website: 'https://apps.gnome.org/Characters/',
-            issue_url: 'https://gitlab.gnome.org/GNOME/gnome-characters/-/issues/new',
-            transient_for: this,
+            issue_url: 'https://gitlab.gnome.org/GNOME/gnome-characters/-/issues/',
         });
 
-        aboutWindow.present();
+        aboutDialog.present(this);
     }
 
     get maxRecentCharacters() {
@@ -246,11 +243,9 @@ var MainWindow = GObject.registerClass({
 
     _handleCharacterSelected(widget, uc) {
         const dialog = new CharacterDialog(uc, this._charactersView.fontDescription);
-        dialog.set_modal(true);
-        dialog.set_transient_for(this.get_root());
         dialog.connect('character-copied', (_widget, char) => {
             this.addToRecent(char);
         });
-        dialog.show();
+        dialog.present(this);
     }
 });
